@@ -34,14 +34,12 @@ library(lattice)
 trellis.device(postscript, file="ch05.ps", width=8, height=6, pointsize=9)
 
 rm(A, B) # precautionary clear-out
-data(shoes)
 attach(shoes)
 tperm <- perm.t.test(B - A) # see section 5.6
 detach()
 
 # from ch04
 if(!exists("fgl.df")) {
-data(fgl)
 fgl0 <- fgl[ ,-10] # omit type.
 fgl.df <- data.frame(type = rep(fgl$type, 9),
   y = as.vector(as.matrix(fgl0)),
@@ -73,7 +71,6 @@ contam <- rnorm( 100, 0, (1 + 2*rbinom(100, 1, 0.05)) )
 
 # 5.3  Data summaries
 
-data(geyser); data(chem); data(abbey)
 par(mfrow=c(2,3))
 hist(geyser$duration, "scott", xlab="duration")
 hist(chem, "scott")
@@ -172,6 +169,25 @@ fitdistr(abbey, "t", list(m = 12, s = 5), df = 10)
 
 # 5.6  Density estimation
 
+# Figure 5.8
+attach(geyser)
+par(mfrow=c(2,3))
+truehist(duration, h=0.5, x0=0.0, xlim=c(0, 6), ymax=0.7)
+truehist(duration, h=0.5, x0=0.1, xlim=c(0, 6), ymax=0.7)
+truehist(duration, h=0.5, x0=0.2, xlim=c(0, 6), ymax=0.7)
+truehist(duration, h=0.5, x0=0.3, xlim=c(0, 6), ymax=0.7)
+truehist(duration, h=0.5, x0=0.4, xlim=c(0, 6), ymax=0.7)
+
+breaks <- seq(0, 5.9, 0.1)
+counts <- numeric(length(breaks))
+for(i in (0:4)) counts[i+(1:55)] <- counts[i+(1:55)] +
+    rep(hist(duration, breaks=0.1*i + seq(0, 5.5, 0.5),
+    prob=TRUE, plot=FALSE)$intensities, rep(5,11))
+plot(breaks+0.05, counts/5, type="l", xlab="duration",
+    ylab="averaged", bty="n", xlim=c(0, 6), ylim=c(0, 0.7))
+detach()
+
+
 attach(geyser)
 truehist(duration, nbins = 15, xlim = c(0.5, 6), ymax = 1.2)
 lines(density(duration, width = "nrd"))
@@ -181,16 +197,15 @@ lines(density(duration, width = "SJ", n = 256), lty = 3)
 lines(density(duration, n = 256, width = "SJ-dpi"), lty = 1)
 detach()
 
-data(galaxies)
 gal <- galaxies/1000
 plot(x = c(0, 40), y = c(0, 0.3), type = "n", bty = "l",
     xlab = "velocity of galaxy (1000km/s)", ylab = "density")
 rug(gal)
 lines(density(gal, width = "SJ-dpi", n = 256), lty = 1)
 lines(density(gal, width = "SJ", n = 256), lty = 3)
-library(logspline)
+library(polspline)
 x <- seq(5, 40, length = 500)
-lines(x, dlogspline(x, logspline.fit(gal)), lty = 2)
+lines(x, doldlogspline(x, oldlogspline(gal)), lty = 2)
 
 
 geyser2 <- data.frame(as.data.frame(geyser)[-1, ],
@@ -224,7 +239,7 @@ truehist(res, h = 0.1)
 lines(density(res, width = "SJ-dpi", n = 256))
 quantile(res, p = c(0.025, 0.975))
 x <- seq(19.5, 22.5, length = 500)
-lines(x, dlogspline(x, logspline.fit(res)), lty = 3)
+lines(x, doldlogspline(x, oldlogspline(res)), lty = 3)
 
 library(boot)
 set.seed(101)
@@ -235,7 +250,7 @@ boot.ci(gal.boot, conf = c(0.90, 0.95),
          type = c("norm","basic","perc","bca"))
 plot(gal.boot)
 
-if(F){
+if(F){ # bootstrap() is an S-PLUS function
 gal.bt <- bootstrap(gal, median, seed = 101, B = 1000)
 summary(gal.bt)
 plot(gal.bt)
